.. py:function:: sf_eta_int(n [, ret])

    Wrapper for :c:func:`gsl_sf_eta_int`
    c code signature: double gsl_sf_eta_int(const int n)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il__Rd__O`
    
    :param int n: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_eta_e(s [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_eta_e`
    c code signature: int gsl_sf_eta_e(const double s, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double s: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_eta_int_e(n [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_eta_int_e`
    c code signature: int gsl_sf_eta_int_e( int n, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il__Rl__Ord`
    
    :param int n: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_eta(s [, ret])

    Wrapper for :c:func:`gsl_sf_eta`
    c code signature: double gsl_sf_eta(const double s)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double s: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_hzeta(s, q [, ret])

    Wrapper for :c:func:`gsl_sf_hzeta`
    c code signature: double gsl_sf_hzeta(const double s, const double q)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rd__O`
    
    :param double s: positional argument 0
    :param double q: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_hzeta_e(s, q [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_hzeta_e`
    c code signature: int gsl_sf_hzeta_e(const double s, const double q, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Ord`
    
    :param double s: positional argument 0
    :param double q: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_zeta(s [, ret])

    Wrapper for :c:func:`gsl_sf_zeta`
    c code signature: double gsl_sf_zeta(const double s)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double s: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_zeta_e(s [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_zeta_e`
    c code signature: int gsl_sf_zeta_e(const double s, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double s: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_zeta_int_e(n [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_zeta_int_e`
    c code signature: int gsl_sf_zeta_int_e(const int n, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il__Rl__Ord`
    
    :param int n: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_zetam1_int_e(s [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_zetam1_int_e`
    c code signature: int gsl_sf_zetam1_int_e(const int s, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il__Rl__Ord`
    
    :param int s: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_zetam1_int(s [, ret])

    Wrapper for :c:func:`gsl_sf_zetam1_int`
    c code signature: double gsl_sf_zetam1_int(const int s)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il__Rd__O`
    
    :param int s: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_zetam1(s [, ret])

    Wrapper for :c:func:`gsl_sf_zetam1`
    c code signature: double gsl_sf_zetam1(const double s)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double s: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_zetam1_e(s [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_zetam1_e`
    c code signature: int gsl_sf_zetam1_e(const double s, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double s: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_zeta_int(n [, ret])

    Wrapper for :c:func:`gsl_sf_zeta_int`
    c code signature: double gsl_sf_zeta_int(const int n)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il__Rd__O`
    
    :param int n: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

